@@ -13,6 +13,8 @@
 #include "Greek2Greek.h"
 #include "bookmarkfrm.h"
 #include "optionfrm.h"
+#include "vrslstfrm.h"
+#include <utilstr.h>
 
 //---------------------------------------------------------------------------
 #pragma resource "*.dfm"
@@ -117,7 +119,8 @@ char TForm1::CreateCommentPane(SWModule *mod) {
 			newrtf = new TPanel(this);
 			((TPanel *)newrtf)->Caption = "Syncronizing to External Viewer";
 			mod->Disp(*displays.insert(displays.begin(), new DispExternal()));
-/*		}
+/*
+		}
 		else {
 	//		newrtf = new THTML(this->Handle);
 	//		newrtf = new SWDispRTF(this);
@@ -189,6 +192,7 @@ void TForm1::TextKeyChanged()
 	cbBook->ItemIndex = cbBook->Items->IndexOf(DefaultVSKey.books[DefaultVSKey.Testament()-1][DefaultVSKey.Book()-1].name);
 	CHBox->Text  = DefaultVSKey.Chapter();
 	VSBox->Text  = DefaultVSKey.Verse();
+	freeHandLookup->Text = (const char *)DefaultVSKey;
 	RefreshActiveSheet(PageControl1);
 	logmodstate = false;		// only log state once
 	RefreshActiveSheet(PageControl2);
@@ -623,3 +627,91 @@ void __fastcall TForm1::FormCreate(TObject *Sender)
 	
 }
 //---------------------------------------------------------------------------
+void __fastcall TForm1::PopupMenuPopup(TObject *Sender)
+{
+
+	int versestart, verseend;
+	TMenuItem * newitem;
+	TPopupMenu *menu = (TPopupMenu *)Sender;
+	int staticMenuItemsCount = ((menu == PopupMenu1) ? 3:2);
+	while (menu->Items->Count > staticMenuItemsCount)
+		menu->Items->Delete(staticMenuItemsCount);
+
+	SWDispRTF *rtf = (SWDispRTF *)Screen->ActiveControl;
+	if (!rtf->SelLength) {
+		for (versestart = rtf->SelStart; ((versestart)&&(rtf->Text[versestart] != '#')); versestart--);
+		if (versestart) {
+			for (verseend = versestart; ((verseend < rtf->Text.Length())&&(rtf->Text[verseend] != '|')); verseend++);
+			if ((verseend < rtf->Text.Length()) && (verseend > rtf->SelStart)) {
+				int len = (verseend - versestart) + 1;
+				char *buf = new char [ len + 1 ];
+				memset(buf, 0 , len + 1);
+				strncpy(buf, &rtf->Text.c_str()[versestart], len - 2);	// strip the # and | from the string
+				tmpVerseList = VerseKey::ParseVerseList(buf);
+
+				ModMap::iterator target;
+				target = mainmgr->Modules.find(((TPageControl*)rtf->Parent->Parent)->ActivePage->Caption.c_str());
+				if (target != Form1->mainmgr->Modules.end()) {
+					char *keytext = 0;		// check for and remove return at end of keytext
+					stdstr(&keytext, (*(*target).second).KeyText());
+					if (keytext[strlen(keytext)-1] == '\r')
+						keytext[strlen(keytext)-1] = 0;
+					
+					tmpVerseListCaption = String("VerseList from- ") + (*target).first.c_str() + ": " + keytext;
+					delete [] keytext;		// ---------------------------------
+				}
+				delete [] buf;
+				newitem = new TMenuItem(menu);
+				newitem->Caption = "-";
+				menu->Items->Add(newitem);
+				newitem = new TMenuItem(menu);
+				newitem->Caption = "Create Verse List";
+				newitem->Hint = "Create a New Verse List Window";
+				newitem->Default = true;
+				newitem->OnClick = createVerseList;
+				menu->Items->Add(newitem);
+				versestart = 3;
+				while (!tmpVerseList.Error()) {
+					versestart++;
+					newitem = new TMenuItem(menu);
+					newitem->Caption = (const char *)tmpVerseList;
+					newitem->OnClick = BookmarkItemClick;
+					if (!(versestart%15))
+						newitem->Break = mbBreak;
+					menu->Items->Add(newitem);
+					tmpVerseList++;
+				}
+			}
+		}
+	}
+	
+}
+//---------------------------------------------------------------------------
+
+
+void __fastcall TForm1::createVerseList(TObject *Sender)
+{
+	TVerseListFrm *tmpForm = new TVerseListFrm(this, tmpVerseList);
+	tmpForm->Caption = tmpVerseListCaption;
+	tmpForm->Show();	
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TForm1::freeHandLookupKeyPress(TObject *Sender, char &Key)
+{
+	if (Key == '\r') {
+		SWListKey &tmpVerseList = VerseKey::ParseVerseList(freeHandLookup->Text.c_str());
+		if (tmpVerseList.Count() > 1) {
+			TVerseListFrm *tmpForm = new TVerseListFrm(this, tmpVerseList);
+			tmpForm->Caption = "User Verse List";
+			tmpForm->Show();
+		}
+		if (tmpVerseList.Count()) {
+			tmpVerseList = TOP;
+			DefaultVSKey = tmpVerseList;
+			TextKeyChanged();
+		}
+	}
+}
+//---------------------------------------------------------------------------
+
