@@ -11,6 +11,7 @@ USEFORM("optionfrm.cpp", Optionsfrm);
 USEFORM("searchfrm.cpp", Form2);
 USEUNIT("biblecsmgr.cpp");
 USEFORM("ModInstForm.cpp", ModInstFrm);
+USEFORM("vrslstfrm.cpp", VerseListFrm);
 //---------------------------------------------------------------------------
 WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
 {
@@ -18,13 +19,14 @@ WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
         {
                  Application->Initialize();
                  Application->CreateForm(__classid(TForm1), &Form1);
-                 Application->CreateForm(__classid(TAboutBox), &AboutBox);
-                 Application->CreateForm(__classid(TBookmarksfrm), &Bookmarksfrm);
-                 Application->CreateForm(__classid(TNewBMfrm), &NewBMfrm);
-                 Application->CreateForm(__classid(TOptionsfrm), &Optionsfrm);
-                 Application->CreateForm(__classid(TForm2), &Form2);
-                 Application->CreateForm(__classid(TModInstFrm), &ModInstFrm);
-                 Application->Run();
+		Application->CreateForm(__classid(TAboutBox), &AboutBox);
+		Application->CreateForm(__classid(TBookmarksfrm), &Bookmarksfrm);
+		Application->CreateForm(__classid(TNewBMfrm), &NewBMfrm);
+		Application->CreateForm(__classid(TOptionsfrm), &Optionsfrm);
+		Application->CreateForm(__classid(TForm2), &Form2);
+		Application->CreateForm(__classid(TModInstFrm), &ModInstFrm);
+		Application->CreateForm(__classid(TVerseListFrm), &VerseListFrm);
+		Application->Run();
         }
         catch (Exception &exception)
         {
