@@ -80,6 +80,167 @@ struct sbook VerseKey::ntbooks[] = {
 };
 
 
+/******************************************************************************
+ *	Abbreviations - MUST be in alphabetical order & by PRIORITY
+ *		RULE: first match of entire key
+ *			(e.g. key: "1CH"; match: "1CHRONICLES")
+ */
+
+struct abbrev VerseKey::abbrevs[] = {
+	{"1 C", 46}, //   1 Corinthians
+	{"1 CHRONICLES", 13}, //   1 Chronicles
+	{"1 CORINTHIANS", 46}, //   1 Corinthians
+	{"1 JOHN", 62}, //    1 John
+	{"1 KINGS", 11   }, //    1 Kings
+	{"1 PETER", 60   }, //    1 Peter
+	{"1 SAMUEL", 9   }, //    1 Samuel
+	{"1 THESSALONIANS", 52   }, //   1 Thessalonians
+	{"1 TIMOTHY", 54   }, //   1 Timothy
+	{"1C", 46}, //   1 Corinthians
+	{"1CHRONICLES", 13}, //   1 Chronicles
+	{"1CORINTHIANS", 46}, //   1 Corinthians
+	{"1JOHN", 63}, //    1 John
+	{"1KINGS", 11   }, //    1 Kings
+	{"1PETER", 60   }, //    1 Peter
+	{"1SAMUEL", 9   }, //    1 Samuel
+	{"1THESSALONIANS", 52   }, //   1 Thessalonians
+	{"1TIMOTHY", 54   }, //   1 Timothy
+	{"2 C", 47   }, //   2 Corinthians
+	{"2 CHRONICLES", 14   }, //   2 Chronicles
+	{"2 CORINTHANS", 47   }, //   2 Corinthians
+	{"2 JOHN", 63   }, //    2 John
+	{"2 KINGS", 12   }, //    2 Kings
+	{"2 PETER", 61   }, //    2 Peter
+	{"2 SAMUEL", 8   }, //    2 Samuel
+	{"2 THESSALONIANS", 53   }, //   2 Thessalonians
+	{"2 TIMOTHY", 55   }, //   2 Timothy
+	{"2C", 47   }, //   2 Corinthians
+	{"2CHRONICLES", 14   }, //   2 Chronicles
+	{"2CORINTHANS", 47   }, //   2 Corinthians
+	{"2JOHN", 63   }, //    2 John
+	{"2KINGS", 12   }, //    2 Kings
+	{"2PETER", 61   }, //    2 Peter
+	{"2SAMUEL", 8   }, //    2 Samuel
+	{"2THESSALONIANS", 53   }, //   2 Thessalonians
+	{"2TIMOTHY", 55   }, //   2 Timothy
+	{"3 JOHN", 64   }, //    3 John
+	{"3JOHN", 64   }, //    3 John
+	{"ACTS", 44   }, //     Acts
+	{"AMOS", 30   }, //    Amos
+	{"APOCALYPSE OF ST. JOHN", 66  }, //    Apocalypse of St. John (Rev.)
+	{"C", 51   }, //    Colossians
+	{"CANTICLE OF CANTICLES", 22  }, //    Canticle of Canticles (Song of S.)
+	{"COLOSSIANS", 51   }, //    Colossians
+	{"D", 5  }, //     Deuteronomy
+	{"DANIEL", 27   }, //    Daniel
+	{"DEUTERONOMY", 5   }, //    Deuteronomy
+	{"E", 49  }, //     Ephesians
+	{"ECCLESIASTES", 21   }, //    Ecclesiastes
+	{"EPHESIANS", 49   }, //    Ephesians
+	{"ESTER", 17   }, //    Ester
+	{"EXODUS", 2   }, //    Exodus
+	{"EZEKIEL", 26   }, //   Ezekiel
+	{"EZRA", 15   }, //   Ezra
+	{"G", 1  }, //     Genesis
+	{"GALATIANS", 48   }, //    Galatians
+	{"GENESIS", 1   }, //    Genesis
+	{"H", 58  }, //     Hebrews
+	{"HABAKKUK", 35   }, //    Habakkuk
+	{"HAGGAI", 37   }, //   Haggai
+	{"HEBREWS", 58   }, //    Hebrews
+	{"HOSEA", 28   }, //    Hosea
+	{"I C", 46}, //   1 Corinthians
+	{"I CHRONICLES", 13}, //   1 Chronicles
+	{"I CORINTHIANS", 46}, //   1 Corinthians
+	{"I JOHN", 62}, //    1 John
+	{"I KINGS", 11   }, //    1 Kings
+	{"I PETER", 60   }, //    1 Peter
+	{"I SAMUEL", 9   }, //    1 Samuel
+	{"I THESSALONIANS", 52   }, //   1 Thessalonians
+	{"I TIMOTHY", 54   }, //   1 Timothy
+	{"IC", 46}, //   1 Corinthians
+	{"ICHRONICLES", 13}, //   1 Chronicles
+	{"ICORINTHIANS", 46}, //   1 Corinthians
+	{"II C", 47   }, //   2 Corinthians
+	{"II CHRONICLES", 14   }, //   2 Chronicles
+	{"II CORINTHANS", 47   }, //   2 Corinthians
+	{"II JOHN", 63   }, //    2 John
+	{"II KINGS", 12   }, //    2 Kings
+	{"II PETER", 61   }, //    2 Peter
+	{"II SAMUEL", 10   }, //    2 Samuel
+	{"II THESSALONIANS", 53   }, //   2 Thessalonians
+	{"II TIMOTHY", 55   }, //   2 Timothy
+	{"IIIJOHN", 64   }, //    3 John
+	{"IIC", 47   }, //   2 Corinthians
+	{"IICHRONICLES", 14   }, //   2 Chronicles
+	{"IICORINTHANS", 47   }, //   2 Corinthians
+	{"III JOHN", 64   }, //    3 John
+	{"IIJOHN", 63   }, //    2 John
+	{"IIKINGS", 12   }, //    2 Kings
+	{"IIPETER", 61   }, //    2 Peter
+	{"IISAMUEL", 10   }, //    2 Samuel
+	{"IITHESSALONIANS", 53   }, //   2 Thessalonians
+	{"IITIMOTHY", 55   }, //   2 Timothy
+	{"IJOHN", 62}, //    1 John
+	{"IKINGS", 11   }, //    1 Kings
+	{"IPETER", 60   }, //    1 Peter
+	{"ISAIAH", 23   }, //     Isaiah
+	{"ISAMUEL", 9   }, //    1 Samuel
+	{"ITHESSALONIANS", 52   }, //   1 Thessalonians
+	{"ITIMOTHY", 54   }, //   1 Timothy
+	{"J", 43  }, //     John
+	{"JAMES", 59   }, //    James
+	{"JAS", 59   }, //    James
+	{"JEREMIAH", 24   }, //    Jeremiah
+	{"JN", 43  }, //    John
+	{"JO", 43  }, //    John
+	{"JOB", 18   }, //   Job
+	{"JOEL", 29   }, //   Joel
+	{"JOHN", 43   }, //   John
+	{"JONAH", 32   }, //   Jonah
+	{"JOSHUA", 6   }, //   Joshua
+	{"JUD", 9   }, //   Judges
+	{"JUDE", 65   }, //  Jude
+	{"JUDGES", 7}, //  Judges
+	{"L", 42}, //     Luke
+	{"LAMENTATIONS", 25}, //    Lamentations
+	{"LEVITICUS", 3}, //    Leviticus
+	{"LK", 42}, //    Luke
+	{"LUKE", 42}, //    Luke
+	{"MA", 40}, //    Matthew
+	{"MALACHI", 39   }, //   Malachi
+	{"MARK", 41}, //   Mark
+	{"MATTHEW", 50}, //   Matthew
+	{"MICAH", 33}, //    Micah
+	{"MK", 41}, //    Mark
+	{"MR", 41}, //    Mark
+	{"MT", 40}, //    Matthew
+	{"N", 4}, //     Numbers
+	{"NAHUM", 34}, //    Nahum
+	{"NEHEMIAH", 16}, //    Nehemiah
+	{"NUMBERS", 4}, //    Numbers
+	{"OBADIAH", 31}, //     Obadiah
+	{"P", 19}, //     Psalms
+	{"PH", 50}, //    Philippians
+	{"PHILEMON", 57}, // Philemon
+	{"PHILIPPIANS", 50}, // Philippians
+	{"PHM", 57}, //   Philemon
+	{"PHP", 50}, //   Philippians
+	{"PSALMS", 19}, //    Psalms
+	{"PROVERBS", 20}, //    Proverbs
+	{"REVELATION", 66}, //     Revelation
+	{"ROMANS", 45}, //    Romans
+	{"RUTH", 8}, //    Ruth
+	{"SONG OF SOLOMON", 22}, //     Song of Solomon
+	{"SONG OF SONGS", 22}, //     Song of Solomon
+	{"TITUS", 56}, //     Titus
+	{"ZECARIAH", 38}, //   Zechariah
+	{"ZEPHANIAH", 36}, //   Zephaniah
+	{"", -1} //   Zephaniah
+};
+
+
+
 /******************************************************************************
  *	Maximum verses per chapter
  */
