@@ -18,12 +18,11 @@ public:
 	operator char() { return pos; }
 };
 
-#define POS_TOP ((char)1);
-#define POS_BOTTOM ((char)2);
-
-#define TOP POSITION(1);
-#define BOTTOM POSITION(2);
+#define POS_TOP ((char)1)
+#define POS_BOTTOM ((char)2)
 
+#define TOP POSITION(1)
+#define BOTTOM POSITION(2)
 
 class SWKey {
 protected:
