@@ -6,8 +6,6 @@
 #include <swmodule.h>
 #include <swconfig.h>
 #include <swlog.h>
-#include <gbfrtf.h>
-#include <rwprtf.h>
 
 using namespace std;
 
