@@ -8,6 +8,7 @@
 #include <stdio.h>
 #include <fcntl.h>
 #include <stdlib.h>
+#include <ctype.h>
 
 #ifndef __GNUC__
 #include <io.h>
@@ -28,7 +29,7 @@ struct sbook *VerseKey::books[2]       = {0,0};
 const char    VerseKey::BMAX[2]        = {39, 27};
 long         *VerseKey::offsets[2][2]  = {{VerseKey::otbks, VerseKey::otcps}, {VerseKey::ntbks, VerseKey::ntcps}};
 int           VerseKey::instance       = 0;
-
+SWListKey     VerseKey::internalListKey;
 
 
 /******************************************************************************
@@ -91,6 +92,8 @@ void VerseKey::initstatics()
 
 char VerseKey::parse()
 {
+
+	
 	testament = 1;
 	book      = 1;
 	chapter   = 1;
@@ -99,21 +102,24 @@ char VerseKey::parse()
 	error     = 0;
 
 	if (keytext) {
-		for (testament = 1; testament < 3; testament++) {
-			for (book = 1; book <= BMAX[testament-1]; book++) {
-				if (!strncmp(keytext, books[testament-1][book-1].name, strlen(books[testament-1][book-1].name)))
+		SWListKey &tmpListKey = VerseKey::ParseVerseList(keytext);
+		if (tmpListKey.Count()) {
+			SWKey::operator =((const char *)tmpListKey);
+			for (testament = 1; testament < 3; testament++) {
+				for (book = 1; book <= BMAX[testament-1]; book++) {
+					if (!strncmp(keytext, books[testament-1][book-1].name, strlen(books[testament-1][book-1].name)))
+						break;
+				}
+				if (book <= BMAX[testament-1])
 					break;
 			}
-			if (book <= BMAX[testament-1])
-				break;
-		}
 
-		if (testament < 3) {
-			sscanf(&keytext[strlen(books[testament-1][book-1].name)], "%d:%d", &chapter, &verse);
+			if (testament < 3) {
+				sscanf(&keytext[strlen(books[testament-1][book-1].name)], "%d:%d", &chapter, &verse);
+			}
+			else	error = 1;
 		}
-		else	error = 1;
 	}
-
 	Normalize(1);
 	freshtext();
 
@@ -141,6 +147,195 @@ void VerseKey::freshtext()
 }
 
 
+
+/******************************************************************************
+ * VerseKey::getBookAbbrev - Attempts to find a book abbreviation for a buffer
+ *
+ * ENT:	abbr - key for which to search;
+ * RET:	book number or < 0 = not valid
+ */
+
+int VerseKey::getBookAbbrev(char *abbr)
+{
+	int loop;
+
+	strstrip(abbr);
+	for (loop = 0; loop < strlen(abbr); loop++)
+		abbr[loop] = toupper(abbr[loop]);
+
+	if (strlen(abbr)) {
+		for (loop = 0; *abbrevs[loop].ab; loop++) {
+			if (!strncmp(abbr, abbrevs[loop].ab, strlen(abbr)))
+				break;
+		}
+		return ((*abbrevs[loop].ab) ? abbrevs[loop].book : -1);
+	}
+	else	return -1;
+}
+
+/******************************************************************************
+ * VerseKey::ParseVerseList - Attempts to parse a buffer into separate
+ *				verse entries returned in an SWListKey
+ *
+ * ENT:	buf - buffer to parse;
+ * RET:	ListKey reference filled with verse entries contained in buf
+ */
+
+SWListKey &VerseKey::ParseVerseList(char *buf)
+{
+	SWKey textkey;
+
+	char book[255];
+	char lastbook[255];
+	char number[255];
+	char lastnumber[255];
+	char tobook = 0;
+	char tonumber = 0;
+	char lastchar = 0;
+	int chap = -1, verse = -1;
+	int bookno;
+	VerseKey curkey;
+	int loop;
+	char comma = 0;
+	char dash = 0;
+
+	internalListKey.ClearList();
+
+	while (*buf) {
+		switch (*buf) {
+		case ':':
+			number[tonumber] = 0;
+			tonumber = 0;
+			if (*number)
+				chap = atoi(number);
+			*number = 0;
+			break;
+
+		case '-':
+		case ',':
+		case ';':
+			number[tonumber] = 0;
+			tonumber = 0;
+			if (*number) {
+				if (chap >= 0)
+					verse = atoi(number);
+				else	chap = atoi(number);
+			}
+			*number = 0;
+			book[tobook] = 0;
+			tobook = 0;
+			bookno = -1;
+			if (*book) {
+				for (loop = strlen(book) - 1; loop+1; loop--) {
+					if ((isdigit(book[loop])) || (book[loop] == ' '))
+						book[loop] = 0;
+					else	break;
+				}
+				bookno = getBookAbbrev(book);
+			}
+			if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
+				curkey.Verse(1);
+				curkey.Chapter(1);
+				curkey.Book(1);
+
+				if (bookno < 0) {
+					curkey.Testament(VerseKey(internalListKey).Testament());
+					curkey.Book(VerseKey(internalListKey).Book());
+				}
+				else {
+					curkey.Testament(1);
+					curkey.Book(bookno);
+				}
+
+				if (comma) {
+					curkey.Chapter(VerseKey(internalListKey).Chapter());
+					curkey.Verse(chap);  // chap because this is the first number captured
+				}
+				else {
+					curkey.Chapter(((chap >=0)?chap:1));
+					curkey.Verse(((verse >=0)?verse:1));
+				}
+
+				if (!dash)
+					internalListKey << curkey;
+			}
+			*book = 0;
+			chap = -1;
+			verse = -1;
+			if (*buf == ',')
+				comma = 1;
+			else	comma = 0;
+			if (*buf == '-')
+				dash = 1;
+			else	dash = 0;
+			break;
+		case 10:	// ignore these
+		case 13: break;
+		default:
+			if (isdigit(*buf)) {
+				number[tonumber++] = *buf;
+			}
+			else {
+				number[tonumber] = 0;
+				tonumber = 0;
+			}
+			book[tobook++] = toupper(*buf);
+		}
+		lastchar = *buf;
+		buf++;
+	}
+	number[tonumber] = 0;
+	tonumber = 0;
+	if (*number) {
+		if (chap >= 0)
+			verse = atoi(number);
+		else	chap = atoi(number);
+	}
+	*number = 0;
+	book[tobook] = 0;
+	tobook = 0;
+	if (*book) {
+		for (loop = strlen(book) - 1; loop+1; loop--) {
+			if ((isdigit(book[loop])) || (book[loop] == ' '))
+				book[loop] = 0;
+			else	break;
+		}
+		bookno = getBookAbbrev(book);
+	}
+	if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
+		curkey.Verse(1);
+		curkey.Chapter(1);
+		curkey.Book(1);
+
+		if (bookno < 0) {
+			curkey.Testament(VerseKey(internalListKey).Testament());
+			curkey.Book(VerseKey(internalListKey).Book());
+		}
+		else {
+			curkey.Testament(1);
+			curkey.Book(bookno);
+		}
+
+		if (comma) {
+			curkey.Chapter(VerseKey(internalListKey).Chapter());
+			curkey.Verse(chap);  // chap because this is the first number captured
+		}
+		else {
+			curkey.Chapter(((chap >=0)?chap:1));
+			curkey.Verse(((verse >=0)?verse:1));
+		}
+
+		if (!dash)
+			internalListKey << curkey;
+	}
+	*book = 0;
+
+	internalListKey = TOP;	// Align internalListKey to first element before passing back;
+
+	return internalListKey;
+}
+
+
 /******************************************************************************
  * VerseKey::operator = - Equates this VerseKey to another VerseKey
  */
